@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,7 +26,7 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
  * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
@@ -193,7 +193,6 @@ public class TimeZoneNames_gsw extends TimeZoneNamesBundle {
             { "ECT", Europe_Central },
             { "CST6CDT", America_Central },
             { "Asia/Gaza", Europe_Eastern },
-            { "Asia/Amman", Europe_Eastern },
             { "Asia/Kabul", Afghanistan },
             { "Africa/Juba", Africa_Central },
             { "Asia/Beirut", Europe_Eastern },
@@ -224,7 +223,6 @@ public class TimeZoneNames_gsw extends TimeZoneNamesBundle {
             { "Africa/Maputo", Africa_Central },
             { "Africa/Maseru", Africa_Southern },
             { "Africa/Niamey", Africa_Western },
-            { "Asia/Damascus", Europe_Eastern },
             { "Europe/Athens", Europe_Eastern },
             { "Europe/Berlin", Europe_Central },
             { "Europe/Lisbon", Europe_Western },
